summaryrefslogtreecommitdiffstats
path: root/kturtle/src/kturtle.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kturtle/src/kturtle.cpp')
-rw-r--r--kturtle/src/kturtle.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kturtle/src/kturtle.cpp b/kturtle/src/kturtle.cpp
index 49f47d11..ffa528f3 100644
--- a/kturtle/src/kturtle.cpp
+++ b/kturtle/src/kturtle.cpp
@@ -650,7 +650,7 @@ void MainWindow::slotMessageDialog(TQString text)
// BEGIN editor connections (undo, redo, cut, copy, paste, cursor, selections, tqfind, tqreplace, linenumbers etc.)
void MainWindow::slotEditor()
{
@@ -716,7 +716,7 @@ void MainWindow::slotClearSelection()
void MainWindow::slotFind()
{
- KAction *a = editor->actionCollection()->action("edit_tqfind");
+ KAction *a = editor->actionCollection()->action("edit_find");
a->activate();
}
@@ -734,7 +734,7 @@ void MainWindow::slotFindPrevious()
void MainWindow::slotReplace()
{
- KAction* a = editor->actionCollection()->action("edit_tqreplace");
+ KAction* a = editor->actionCollection()->action("edit_replace");
a->activate();
}
@@ -1071,7 +1071,7 @@ void MainWindow::slotContextHelpUpdate()
int start, length, pos;
pos = 0;
- if ( line.tqcontains('"') )
+ if ( line.contains('"') )
{
TQRegExp delimitedStrings("(\"[^\"\\\\\\r\\n]*(\\\\.[^\"\\\\\\r\\n]*)*\")");
while ( delimitedStrings.search(line, pos) != -1 )
@@ -1112,13 +1112,13 @@ void MainWindow::slotContextHelpUpdate()
else if ( !translate->name2key( cursorWord.lower() ).isEmpty() ) helpKeyword = cursorWord;
else if ( !translate->alias2key( cursorWord.lower() ).isEmpty() ) helpKeyword = cursorWord;
- else if ( cursorWord.tqfind( TQRegExp("[\\d.]+") ) == 0 ) helpKeyword = i18n("<number>");
+ else if ( cursorWord.find( TQRegExp("[\\d.]+") ) == 0 ) helpKeyword = i18n("<number>");
- else if ( cursorWord.tqfind( TQRegExp("[+\\-*/\\(\\)]") ) == 0 ) helpKeyword = i18n("<math>");
+ else if ( cursorWord.find( TQRegExp("[+\\-*/\\(\\)]") ) == 0 ) helpKeyword = i18n("<math>");
else if ( cursorWord == TQString("=") ) helpKeyword = i18n("<assignment>");
- else if ( cursorWord.tqfind( TQRegExp("==|<|>|<=|>=|!=") ) == 0 ) helpKeyword = i18n("<question>");
+ else if ( cursorWord.find( TQRegExp("==|<|>|<=|>=|!=") ) == 0 ) helpKeyword = i18n("<question>");
// if we come here we either have an ID of some sort or an error
// all we can do is try to catch some errors (TODO) and then...
@@ -650,7 +650,7 @@ void MainWindow::slotMessageDialog(TQString text)
-// BEGIN editor connections (undo, redo, cut, copy, paste, cursor, selections, tqfind, tqreplace, linenumbers etc.)
+// BEGIN editor connections (undo, redo, cut, copy, paste, cursor, selections, find, replace, linenumbers etc.)
void MainWindow::slotEditor()
{